@@ -90,10 +90,6 @@ def titleSummaryMaker(csv):
 
 def csvImporter(csv_folder, csv_folder_encoding, csv_folder_cleaned, db_table_name):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
-        
-    # csv 줄밀림 정제
-    csvEncoder(csv_folder, csv_folder_encoding)
-    csvCleaner(csv_folder, csv_folder_cleaned)
 
     fileList = os.listdir(csv_folder_cleaned)
     for i in range(len(fileList)):
@@ -122,15 +118,16 @@ def addPoolColumn(dataframe, keyword_pool):
     final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
 
     return final_df
+
+def csvPreprocess(csv_folder, csv_folder_cleaned, csv_folder_encoding):
+    # csv 줄밀림 정제
+    csvEncoder(csv_folder, csv_folder_encoding)
+    csvCleaner(csv_folder_encoding, csv_folder_cleaned)
     
 
 def csvImporter_NEW(csv_folder, csv_folder_cleaned, csv_folder_encoding, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
     
-    # csv 줄밀림 정제
-    csvEncoder(csv_folder, csv_folder_encoding)
-    csvCleaner(csv_folder, csv_folder_cleaned)
-
     # 키워드 풀 가져오기
     pool = keywordPool(keyword_pool)
     title_mapping = titleSummaryMaker(keyword_pool)
@@ -174,9 +171,6 @@ def csvImporter_NEW(csv_folder, csv_folder_cleaned, csv_folder_encoding, keyword
 
 def keywordCheck(csv_folder, csv_folder_cleaned, csv_folder_encoding, pool_check_folder, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
-    # csv 줄밀림 정제
-    csvEncoder(csv_folder, csv_folder_encoding)
-    csvCleaner(csv_folder_cleaned, csv_folder_encoding)
 
     # 키워드 풀 가져오기
     pool = keywordPool(keyword_pool)
@@ -205,10 +199,11 @@ def keywordCheck(csv_folder, csv_folder_cleaned, csv_folder_encoding, pool_check
         check_frame['title_summary_temp'] = check_frame['title_summary_list'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
         
         #키워드 분류로 한번 더 매핑
-        final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
+        final_df = pd.merge(check_frame, title_mapping, how='left', on='title_summary_temp')
 
         #pool 폴더로 검수용 파일 반환
-        final_df.to_csv(pool_check_folder + "\\Keyword_Check" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
+        final_df.to_csv(pool_check_folder + "\\Keyword_Check_" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
+        print("Keyword_Check_" + fileList[i] + "is created")
 
 
 # if __name__ == "__main__":
